@@ -60,8 +60,6 @@ ComicMainWindow::ComicMainWindow(QWidget *parent): QMainWindow(parent), view(NUL
     cfg->restoreGeometry(this);
 
     pageLoader = new PageLoaderThread();
-    connect(pageLoader, SIGNAL(pageLoaded(const Page &)), this, SLOT(pageLoaded(const Page &)));
-    connect(pageLoader, SIGNAL(pageLoaded(const Page &, const Page &)), this, SLOT(pageLoaded(const Page &, const Page &)));
 
     //
     // Thumbnails window
@@ -309,6 +307,8 @@ void ComicMainWindow::setupComicImageView()
     connect(view, SIGNAL(currentPageChanged(int)), this, SLOT(currentPageChanged(int)));
     connect(pageLoader, SIGNAL(pageLoaded(const Page&)), view, SLOT(setImage(const Page&)));
     connect(pageLoader, SIGNAL(pageLoaded(const Page&, const Page&)), view, SLOT(setImage(const Page&, const Page&)));
+    connect(view, SIGNAL(pageReady(const Page &)), this, SLOT(pageLoaded(const Page &)));
+    connect(view, SIGNAL(pageReady(const Page &, const Page &)), this, SLOT(pageLoaded(const Page &, const Page &)));
     connect(view, SIGNAL(requestPage(int)), pageLoader, SLOT(request(int)));
     connect(view, SIGNAL(requestTwoPages(int)), pageLoader, SLOT(requestTwoPages(int)));
     connect(view, SIGNAL(cancelPageRequest(int)), pageLoader, SLOT(cancel(int)));
@@ -486,27 +486,32 @@ void ComicMainWindow::setRecentFilesMenu(const History &hist)
         foreach (QAction *a, actions) {
             a->deleteLater();
         }
-        for (QStringList::const_iterator it = list.begin(); it != list.end(); it++)
-                menuRecentFiles->addAction(*it);
+
+        foreach (const QString &s, list)
+        {
+            QAction *a = menuRecentFiles->addAction(Utility::shortenPath(s, "...", 64));
+            a->setData(s);
+        }
 }
 
 void ComicMainWindow::recentSelected(QAction *action) 
 {
-        const QString &fname = action->text();
-        if (fname != QString::null)
+    const QString fname(action->data().toString());
+    if (fname != QString::null)
+    {
+        QFileInfo finfo(fname);
+        if (!finfo.exists())
         {
-                QFileInfo finfo(fname);
-                if (!finfo.exists())
-                {
-                        recentfiles->remove(fname);
-                        menuRecentFiles->removeAction(action);
-                }
-                open(fname, 0);
+            recentfiles->remove(fname);
+            menuRecentFiles->removeAction(action);
         }
+        open(fname, 0);
+    }
 }
 
 void ComicMainWindow::pageLoaded(const Page &page)
 {
+    qDebug() << "page ready " << page.getNumber();
     if (currpage == page.getNumber())
     {
         statusbar->setImageInfo(&page);
@@ -515,6 +520,7 @@ void ComicMainWindow::pageLoaded(const Page &page)
 
 void ComicMainWindow::pageLoaded(const Page &page1, const Page &page2)
 {
+    qDebug() << "page ready " << page1.getNumber() << ", " << page2.getNumber();
     if (currpage == page1.getNumber() || currpage == page2.getNumber())
     {
         statusbar->setImageInfo(&page1, &page2);
@@ -803,11 +809,11 @@ void ComicMainWindow::showSysInfo()
 void ComicMainWindow::showAbout()
 {
         AboutDialog *win = new AboutDialog(this, "About QComicBook",
-                        "QComicBook " VERSION " - comic book viewer for GNU/Linux\n"
-                        "(c)by Pawel Stolowski 2005-2009\n"
-                        "released under terms of GNU General Public License\n\n"
-                        "http://linux.bydg.org/~yogin\n"
-                        "stolowski@gmail.com", QPixmap(DATADIR "/qcomicbook-splash.png"));
+                        "QComicBook " VERSION " - comic book viewer for GNU/Linux<br>"
+                        "(c)by Pawel Stolowski 2005-2010<br>"
+                        "released under terms of GNU General Public License<br><br>"
+                        "<a href=\"http://qcomicbook.linux-projects.net\">http://qcomicbook.linux-projects.net</a><br>"
+                        "<a href=\"mailto:stolowski@gmail.com\">stolowski@gmail.com</a>", QPixmap(":/images/qcomicbook-splash.png"));
         win->show();
 }
 
