@@ -21,11 +21,11 @@
 #include <QRegExp>
 #include <QApplication>
 #include <QDir>
-#include <stdlib.h>
 #include <stdio.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <unistd.h>
+#include <time.h>
 
 using namespace QComicBook;
 using Utility::which;
@@ -251,11 +251,31 @@ void ImgArchiveSink::extractStdoutReady()
 
 QString ImgArchiveSink::makeTempDir(const QString &parent)
 {
-	char tmpd[1024];
-	const QString pattern = parent + QDir::separator() + "qcomic-XXXXXX";
-	strcpy(tmpd, pattern.toLatin1());
-	mkdtemp(tmpd);
-	return QString(tmpd);
+    static bool initsrand = false;
+
+    //
+    // make sure srand is called only once
+    if (!initsrand)
+    {
+        srand(time(NULL));
+        initsrand = true;
+    }
+
+    QDir dir(parent);
+    for (;;)
+    {
+        const int n = rand();
+        const QString tmpd = QString("qcomic-") + QString::number(n);
+        if (!dir.exists(tmpd))
+        {
+            if (!dir.mkdir(tmpd))
+            {
+                break;
+            }
+            return parent + QDir::separator() + tmpd;
+        }
+    }
+    return QString::null;
 }
 
 bool ImgArchiveSink::supportsNext() const
