@@ -1,7 +1,7 @@
 /*
  * This file is a part of QComicBook.
  *
- * Copyright (C) 2005-2006 Pawel Stolowski <pawel.stolowski@wp.pl>
+ * Copyright (C) 2005-2010 Pawel Stolowski <stolowski@gmail.com>
  *
  * QComicBook is free software; you can redestribute it and/or modify it
  * under terms of GNU General Public License by Free Software Foundation.
@@ -14,6 +14,9 @@
 #include <QMessageBox>
 #include <QSplashScreen>
 #include <QTimer>
+#include <QLibraryInfo>
+#include <QTranslator>
+#include <QLocale>
 #include "ComicMainWindow.h"
 #include "ComicBookSettings.h"
 #include "Thumbnail.h"
@@ -25,6 +28,20 @@ int main(int argc, char *argv[])
 	using namespace QComicBook;
 
 	QApplication app(argc, argv);
+        app.setApplicationName("QComicBook");
+        app.setOrganizationName("PawelStolowski");
+        app.setOrganizationDomain("linux-projects.net");
+
+        //
+        // load translation
+        QTranslator qtTrans;
+        qtTrans.load("qt_" + QLocale::system().name(), QLibraryInfo::location(QLibraryInfo::TranslationsPath));
+        app.installTranslator(&qtTrans);
+
+        QTranslator qcomicbookTrans;
+        qcomicbookTrans.load("qcomicbook_" + QLocale::system().name(), DATADIR "/i18n");
+        app.installTranslator(&qcomicbookTrans);
+
 	const QString errcaption = ComicMainWindow::tr("QComicBook error");
 
         qRegisterMetaType<Page>("Page");
